summaryrefslogtreecommitdiffstats
path: root/src/mesa/main/matrix.c
diff options
context:
space:
mode:
authorKristian Høgsberg <krh@bitplanet.net>2010-10-12 12:26:10 -0400
committerKristian Høgsberg <krh@bitplanet.net>2010-10-13 09:43:25 -0400
commitf9995b30756140724f41daf963fa06167912be7f (patch)
treebc34fd4db5eb9d2ad55968cb4e6e4e5a65df5a27 /src/mesa/main/matrix.c
parent31aca27c08d6a385c595d34fe4ee06390bf5b0e8 (diff)
downloadexternal_mesa3d-f9995b30756140724f41daf963fa06167912be7f.zip
external_mesa3d-f9995b30756140724f41daf963fa06167912be7f.tar.gz
external_mesa3d-f9995b30756140724f41daf963fa06167912be7f.tar.bz2
Drop GLcontext typedef and use struct gl_context instead
Diffstat (limited to 'src/mesa/main/matrix.c')
-rw-r--r--src/mesa/main/matrix.c40
1 files changed, 20 insertions, 20 deletions
diff --git a/src/mesa/main/matrix.c b/src/mesa/main/matrix.c
index 8ed718c..105d4a3 100644
--- a/src/mesa/main/matrix.c
+++ b/src/mesa/main/matrix.c
@@ -59,7 +59,7 @@
*
* Flushes vertices and validates parameters. Calls _math_matrix_frustum() with
* the top matrix of the current matrix stack and sets
- * __GLcontextRec::NewState.
+ * __struct gl_contextRec::NewState.
*/
void GLAPIENTRY
_mesa_Frustum( GLdouble left, GLdouble right,
@@ -101,7 +101,7 @@ _mesa_Frustum( GLdouble left, GLdouble right,
*
* Flushes vertices and validates parameters. Calls _math_matrix_ortho() with
* the top matrix of the current matrix stack and sets
- * __GLcontextRec::NewState.
+ * __struct gl_contextRec::NewState.
*/
void GLAPIENTRY
_mesa_Ortho( GLdouble left, GLdouble right,
@@ -139,7 +139,7 @@ _mesa_Ortho( GLdouble left, GLdouble right,
* \sa glMatrixMode().
*
* Flushes the vertices, validates the parameter and updates
* __GLcontextRec::CurrentStack and gl_transform_attrib::MatrixMode with the
* specified matrix stack.
*/
void GLAPIENTRY
@@ -231,7 +231,7 @@ _mesa_MatrixMode( GLenum mode )
* \sa glPushMatrix().
*
* Verifies the current matrix stack is not full, and duplicates the top-most
* matrix in the stack. Marks __GLcontextRec::NewState with the stack dirty
* flag.
*/
void GLAPIENTRY
@@ -271,7 +271,7 @@ _mesa_PushMatrix( void )
* \sa glPopMatrix().
*
* Flushes the vertices, verifies the current matrix stack is not empty, and
* moves the stack head down. Marks __GLcontextRec::NewState with the dirty
* stack flag.
*/
void GLAPIENTRY
@@ -309,7 +309,7 @@ _mesa_PopMatrix( void )
* \sa glLoadIdentity().
*
* Flushes the vertices and calls _math_matrix_set_identity() with the top-most
* matrix in the current stack. Marks __GLcontextRec::NewState with the stack
* dirty flag.
*/
void GLAPIENTRY
@@ -334,7 +334,7 @@ _mesa_LoadIdentity( void )
* \sa glLoadMatrixf().
*
* Flushes the vertices and calls _math_matrix_loadf() with the top-most matrix
* in the current stack and the given matrix. Marks __GLcontextRec::NewState
* with the dirty stack flag.
*/
void GLAPIENTRY
@@ -365,7 +365,7 @@ _mesa_LoadMatrixf( const GLfloat *m )
*
* Flushes the vertices and calls _math_matrix_mul_floats() with the top-most
* matrix in the current stack and the given matrix. Marks
* __GLcontextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
_mesa_MultMatrixf( const GLfloat *m )
@@ -397,7 +397,7 @@ _mesa_MultMatrixf( const GLfloat *m )
*
* Flushes the vertices and calls _math_matrix_rotate() with the top-most
* matrix in the current stack and the given parameters. Marks
* __GLcontextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
_mesa_Rotatef( GLfloat angle, GLfloat x, GLfloat y, GLfloat z )
@@ -422,7 +422,7 @@ _mesa_Rotatef( GLfloat angle, GLfloat x, GLfloat y, GLfloat z )
*
* Flushes the vertices and calls _math_matrix_scale() with the top-most
* matrix in the current stack and the given parameters. Marks
* __GLcontextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
_mesa_Scalef( GLfloat x, GLfloat y, GLfloat z )
@@ -445,7 +445,7 @@ _mesa_Scalef( GLfloat x, GLfloat y, GLfloat z )
*
* Flushes the vertices and calls _math_matrix_translate() with the top-most
* matrix in the current stack and the given parameters. Marks
* __GLcontextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
_mesa_Translatef( GLfloat x, GLfloat y, GLfloat z )
@@ -559,13 +559,13 @@ _mesa_MultTransposeMatrixdARB( const GLdouble *m )
* Calls _math_matrix_analyse() with the top-matrix of the projection matrix
* stack, and recomputes user clip positions if necessary.
*
* \note This routine references __GLcontextRec::Tranform attribute values to
* compute userclip positions in clip space, but is only called on
* _NEW_PROJECTION. The _mesa_ClipPlane() function keeps these values up to
* date across changes to the __GLcontextRec::Transform attributes.
*/
static void
-update_projection( GLcontext *ctx )
+update_projection( struct gl_context *ctx )
{
_math_matrix_analyse( ctx->ProjectionMatrixStack.Top );
@@ -593,11 +593,11 @@ update_projection( GLcontext *ctx )
* \param ctx GL context.
*
* Multiplies the top matrices of the projection and model view stacks into
- * __GLcontextRec::_ModelProjectMatrix via _math_matrix_mul_matrix() and
+ * __struct gl_contextRec::_ModelProjectMatrix via _math_matrix_mul_matrix() and
* analyzes the resulting matrix via _math_matrix_analyse().
*/
static void
-calculate_model_project_matrix( GLcontext *ctx )
+calculate_model_project_matrix( struct gl_context *ctx )
{
_math_matrix_mul_matrix( &ctx->_ModelProjectMatrix,
ctx->ProjectionMatrixStack.Top,
@@ -618,7 +618,7 @@ calculate_model_project_matrix( GLcontext *ctx )
* calculate_model_project_matrix() to recalculate the modelview-projection
* matrix.
*/
-void _mesa_update_modelview_project( GLcontext *ctx, GLuint new_state )
+void _mesa_update_modelview_project( struct gl_context *ctx, GLuint new_state )
{
if (new_state & _NEW_MODELVIEW) {
_math_matrix_analyse( ctx->ModelviewMatrixStack.Top );
@@ -712,7 +712,7 @@ free_matrix_stack( struct gl_matrix_stack *stack )
* Initializes each of the matrix stacks and the combined modelview-projection
* matrix.
*/
-void _mesa_init_matrix( GLcontext * ctx )
+void _mesa_init_matrix( struct gl_context * ctx )
{
GLint i;
@@ -742,7 +742,7 @@ void _mesa_init_matrix( GLcontext * ctx )
* Frees each of the matrix stacks and the combined modelview-projection
* matrix.
*/
-void _mesa_free_matrix_data( GLcontext *ctx )
+void _mesa_free_matrix_data( struct gl_context *ctx )
{
GLint i;
@@ -765,7 +765,7 @@ void _mesa_free_matrix_data( GLcontext *ctx )
*
* \todo Move this to a new file with other 'transform' routines.
*/
-void _mesa_init_transform( GLcontext *ctx )
+void _mesa_init_transform( struct gl_context *ctx )
{
GLint i;
@@ -139,7 +139,7 @@ _mesa_Ortho( GLdouble left, GLdouble right,
*
* Flushes the vertices, validates the parameter and updates
- * __GLcontextRec::CurrentStack and gl_transform_attrib::MatrixMode with the
+ * __struct gl_contextRec::CurrentStack and gl_transform_attrib::MatrixMode with the
* specified matrix stack.
*/
@@ -231,7 +231,7 @@ _mesa_MatrixMode( GLenum mode )
*
* Verifies the current matrix stack is not full, and duplicates the top-most
- * matrix in the stack. Marks __GLcontextRec::NewState with the stack dirty
+ * matrix in the stack. Marks __struct gl_contextRec::NewState with the stack dirty
* flag.
*/
@@ -271,7 +271,7 @@ _mesa_PushMatrix( void )
*
* Flushes the vertices, verifies the current matrix stack is not empty, and
- * moves the stack head down. Marks __GLcontextRec::NewState with the dirty
+ * moves the stack head down. Marks __struct gl_contextRec::NewState with the dirty
* stack flag.
*/
@@ -309,7 +309,7 @@ _mesa_PopMatrix( void )
*
* Flushes the vertices and calls _math_matrix_set_identity() with the top-most
- * matrix in the current stack. Marks __GLcontextRec::NewState with the stack
+ * matrix in the current stack. Marks __struct gl_contextRec::NewState with the stack
* dirty flag.
*/
@@ -334,7 +334,7 @@ _mesa_LoadIdentity( void )
*
* Flushes the vertices and calls _math_matrix_loadf() with the top-most matrix
- * in the current stack and the given matrix. Marks __GLcontextRec::NewState
+ * in the current stack and the given matrix. Marks __struct gl_contextRec::NewState
* with the dirty stack flag.
*/
@@ -365,7 +365,7 @@ _mesa_LoadMatrixf( const GLfloat *m )
* Flushes the vertices and calls _math_matrix_mul_floats() with the top-most
* matrix in the current stack and the given matrix. Marks
- * __GLcontextRec::NewState with the dirty stack flag.
+ * __struct gl_contextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
@@ -397,7 +397,7 @@ _mesa_MultMatrixf( const GLfloat *m )
* Flushes the vertices and calls _math_matrix_rotate() with the top-most
* matrix in the current stack and the given parameters. Marks
- * __GLcontextRec::NewState with the dirty stack flag.
+ * __struct gl_contextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
@@ -422,7 +422,7 @@ _mesa_Rotatef( GLfloat angle, GLfloat x, GLfloat y, GLfloat z )
* Flushes the vertices and calls _math_matrix_scale() with the top-most
* matrix in the current stack and the given parameters. Marks
- * __GLcontextRec::NewState with the dirty stack flag.
+ * __struct gl_contextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
@@ -445,7 +445,7 @@ _mesa_Scalef( GLfloat x, GLfloat y, GLfloat z )
* Flushes the vertices and calls _math_matrix_translate() with the top-most
* matrix in the current stack and the given parameters. Marks
- * __GLcontextRec::NewState with the dirty stack flag.
+ * __struct gl_contextRec::NewState with the dirty stack flag.
*/
void GLAPIENTRY
@@ -559,13 +559,13 @@ _mesa_MultTransposeMatrixdARB( const GLdouble *m )
* stack, and recomputes user clip positions if necessary.
*
- * \note This routine references __GLcontextRec::Tranform attribute values to
+ * \note This routine references __struct gl_contextRec::Tranform attribute values to
* compute userclip positions in clip space, but is only called on
* _NEW_PROJECTION. The _mesa_ClipPlane() function keeps these values up to
@@ -559,13 +559,13 @@ _mesa_MultTransposeMatrixdARB( const GLdouble *m )
* compute userclip positions in clip space, but is only called on
* _NEW_PROJECTION. The _mesa_ClipPlane() function keeps these values up to
- * date across changes to the __GLcontextRec::Transform attributes.
+ * date across changes to the __struct gl_contextRec::Transform attributes.
*/
static void